@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # PyKDE; see the file LICENSE.  If not, write to the Free Software Foundation,
-# Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #
 # This module is intended to be used by the configuration scripts of extension
 # modules that %Import PyKDE modules.
@@ -27,17 +27,17 @@ import sipconfig, pyqtconfig
 
 # These are installation specific values created when PyQt was configured.
 _pkg_config = {
-    'kde_version':          0x030402,
+    'kde_version':          0x030507,
     'kde_version_extra':    'kdecvs',
     'kde_version_sfx':      '-kdecvs.diff',
-    'kde_version_str':      '3.4.2',
-    'kdebasedir':           '/opt/kde',
-    'kdeincdir':            '/opt/kde/include',
-    'kdelibdir':            '/opt/kde/lib',
-    'pykde_kde_sip_flags':  '-x Qt_STYLE_WINDOWSXP -x Qt_STYLE_CDE -x Qt_STYLE_MOTIFPLUS -x Qt_STYLE_PLATINUM -x Qt_STYLE_SGI -x Qt_STYLE_WINDOWS -x Qt_STYLE_CDE -x Qt_STYLE_INTERLACE -x Qt_STYLE_MOTIFPLUS -x Qt_STYLE_PLATINUM -x Qt_STYLE_SGI -x Qt_STYLE_WINDOWSXP -x Qt_STYLE_WINDOWS -t WS_X11 -t Qt_3_3_0 -t KDE_3_3_0',
-    'pykde_mod_dir':        '/usr/lib/python2.4/site-packages',
+    'kde_version_str':      '3.5.7',
+    'kdebasedir':           '/usr',
+    'kdeincdir':            '/usr/include',
+    'kdelibdir':            '/usr/lib',
+    'pykde_kde_sip_flags':  '-x Qt_STYLE_WINDOWSXP -x Qt_STYLE_CDE -x Qt_STYLE_MOTIFPLUS -x Qt_STYLE_PLATINUM -x Qt_STYLE_SGI -x Qt_STYLE_WINDOWS -x Qt_STYLE_CDE -x Qt_STYLE_INTERLACE -x Qt_STYLE_MOTIFPLUS -x Qt_STYLE_PLATINUM -x Qt_STYLE_SGI -x Qt_STYLE_WINDOWSXP -x Qt_STYLE_WINDOWS -x VendorID -t WS_X11 -t Qt_3_3_0 -t KDE_3_3_0',
+    'pykde_mod_dir':        '/usr/lib/python2.5/site-packages',
     'pykde_modules':        'dcop kdecore kdesu kdefx kdeui kio kutils kfile kparts khtml kspell kdeprint kmdi',
-    'pykde_sip_dir':        '/opt/kde/share/sip/',
+    'pykde_sip_dir':        '/usr/share/sip/',
     'pykde_version':        0x030b03,
     'pykde_version_str':    '3.11.3'
 }
