@@ -23,23 +23,23 @@ import types
 # These are installation specific values created when SIP was configured.
 _pkg_config = {
     'default_bin_dir':  '/usr/bin',
-    'default_mod_dir':  '/usr/lib/python2.4/site-packages',
-    'default_sip_dir':  '/opt/kde/share/sip',
+    'default_mod_dir':  '/usr/lib/python2.5/site-packages',
+    'default_sip_dir':  '/usr/share/sip',
     'export_all':       0,
-    'py_inc_dir':       '/usr/include/python2.4',
-    'py_lib_dir':       '/usr/lib/python2.4/config',
-    'py_version':       0x020403,
+    'py_inc_dir':       '/usr/include/python2.5',
+    'py_lib_dir':       '/usr/lib/python2.5/config',
+    'py_version':       0x020501,
     'qt_dir':           '/usr/lib/qt/',
     'qt_edition':       'free',
     'qt_inc_dir':       '/usr/lib/qt/include',
     'qt_lib':           'qt-mt',
     'qt_lib_dir':       '/usr/lib/qt//lib',
     'qt_threaded':      1,
-    'qt_version':       0x030306,
+    'qt_version':       0x030308,
     'qt_winconfig':     '',
-    'sip_bin':          '/opt/kde/bin/sip',
-    'sip_inc_dir':      '/usr/include/python2.4',
-    'sip_mod_dir':      '/usr/lib/python2.4/site-packages',
+    'sip_bin':          '/usr/bin/sip',
+    'sip_inc_dir':      '/usr/include/python2.5',
+    'sip_mod_dir':      '/usr/lib/python2.5/site-packages',
     'sip_version':      0x040201,
     'sip_version_str':  '4.2.1'
 }
@@ -64,7 +64,7 @@ _default_macros = {
     'CFLAGS_STL_OFF':           '',
     'CFLAGS_STL_ON':            '',
     'CFLAGS_THREAD':            '-D_REENTRANT',
-    'CFLAGS_WARN_OFF':          '-w',
+    'CFLAGS_WARN_OFF':          '',
     'CFLAGS_WARN_ON':           '-Wall -W',
     'CHK_DIR_EXISTS':           'test -d',
     'COPY':                     'cp -f',
@@ -85,7 +85,7 @@ _default_macros = {
     'CXXFLAGS_STL_OFF':         '',
     'CXXFLAGS_STL_ON':          '',
     'CXXFLAGS_THREAD':          '-D_REENTRANT',
-    'CXXFLAGS_WARN_OFF':        '-w',
+    'CXXFLAGS_WARN_OFF':        '',
     'CXXFLAGS_WARN_ON':         '-Wall -W',
     'DEFINES':                  '',
     'DEL_FILE':                 'rm -f',
